@@ -810,19 +810,19 @@ render_element (GduVolumeGrid *grid,
     gtk_render_focus (context, cr, x + 2, y + 2, w - 4, h - 4);
   if (element->unused > 0)
     {
+      GtkStyleContext *style;
+      GdkRGBA color;
       gdouble unused_height = element->unused * h / element->size;
-      cairo_pattern_t *gradient;
       cairo_save (cr);
-      gradient = cairo_pattern_create_linear (x, y + unused_height - 10, x, y + unused_height);
-      cairo_pattern_add_color_stop_rgba (gradient, 0.0,  1.0, 1.0, 1.0, 0.25);
-      cairo_pattern_add_color_stop_rgba (gradient, 1.0,  1.0, 1.0, 1.0, 0.00);
-      cairo_set_source (cr, gradient);
-      cairo_pattern_destroy (gradient);
+      style = gtk_widget_get_style_context (GTK_WIDGET (grid));
+      gtk_style_context_lookup_color (style, "theme_base_color", &color);
+      color.alpha = 0.25;
+      gdk_cairo_set_source_rgba (cr, &color);
       cairo_rectangle (cr,
-                       x,
-                       y,
-                       w,
-                       unused_height);
+                       x + 1,
+                       y + 1,
+                       w - 2,
+                       unused_height - 2);
       cairo_fill (cr);
       cairo_restore (cr);
     }
@@ -1549,14 +1549,14 @@ maybe_add_partition (GduVolumeGrid   *grid,
       /* Translators: This is shown in the volume grid for a partition with a name/label.
        *              The %d is the partition number. The %s is the name
        */
-      s = g_strdup_printf (C_("volume-grid", "Partition %d: %s"), number, name);
+      s = g_strdup_printf (C_("volume-grid", "Partition %u: %s"), number, name);
     }
   else
     {
       /* Translators: This is shown in the volume grid for a partition with no name/label.
        *              The %d is the partition number
        */
-      s = g_strdup_printf (C_("volume-grid", "Partition %d"), number);
+      s = g_strdup_printf (C_("volume-grid", "Partition %u"), number);
     }
   g_ptr_array_add (lines, s);
 
